(v0.11.2)=
### 0.11.2 {small}`2025-01-07`

#### Bug fixes

- Cache accesses to the `data` and `indices` arrays in {class}`~anndata.abc.CSRDataset` and {class}`~anndata.abc.CSCDataset` {user}`ilan-gold` ({pr}`1744`)
- Error out on floating point indices that are not actually integers {user}`ilan-gold` ({pr}`1746`)
- `write_elem` now filters out incompatible `dataset_kwargs` when saving zero-dimensional arrays {user}`ilia-kats` ({pr}`1783`)
- Add {mod}`scipy` 1.5 compatibility {user}`flying-sheep` ({pr}`1806`)

### Performance

- Batch slice-based indexing in {class}`anndata.abc.CSRDataset` and {class}`anndata.abc.CSCDataset` for performance boost in `zarr` {user}`ilan-gold` ({pr}`1790`)
